@@ -1,53 +1,49 @@
-#' Compute a grobner basis of a list of multivariate polynomials.
+#' REMOVED -- Compute a grobner basis of a list of multivariate 
+#' polynomials.
 #' 
-#' grobner computes a Groebner basis for a collection of multivarite
-#' polynomials represented as an object of class mpolyList. Note
+#' This function has been removed to eliminate mpoly's dependence on
+#' packages that only it uses.  To compute a Grobner basis of a 
+#' collection of multivariate polynomials, checkout the new m2r
+#' package, which you can download with the code in the first example.
+#' 
+#' grobner computes a Grobner basis for a collection of multivarite 
+#' polynomials represented as an object of class mpolyList. Note 
 #' that the polynomials printed after calculation are unlikely to be
-#' properly ordered; this is because the order of the monomials
-#' displayed is governed by the print method, not the mpoly's
+#' properly ordered; this is because the order of the monomials 
+#' displayed is governed by the print method, not the mpoly's 
 #' themselves.
 #' 
 #' @param mpolyList an object of class mpolyList
 #' @param varorder order of variables
-#' @param order total order to be considered for monomials (e.g.
+#' @param order total order to be considered for monomials (e.g. 
 #'   lexicographic)
 #' @return An object of class mpolyList.
 #' @export
 #' @examples
 #' \dontrun{
-#' polys <- mp(c('t^4 - x', 't^3 - y', 't^2 - z'))
-#' grobner(polys)
-#' # result
-#' # -1 z  +  t^2
-#' # t y  -  z^2
-#' # -1 y  +  t z
-#' # x  -  z^2
-#' # y^2  -  z^3
-#' 
-#' grobner(polys, varorder = c('x','y','t','z'))
-#' # x  -  z^2
-#' # y  -  z t
-#' # -1 z  +  t^2
-#' 
-#' polys <- mp(c('x^2 - 2 y^2', 'x y - 3'))
-#' grobner(polys, varorder = c('x', 'y'))
-#' # result
-#' # 3 x  -  2 y^3
-#' # 2 y^4  -  9
-#' 
-#' # using a different monomial order
-#' grobner(polys, varorder = c('x', 'y'), order = 'grlex')
-#' # -3 x  +  2 y^3
-#' # x^2  -  2 y^2
-#' # -3  +  x y
 #' 
 #' 
-#' # example from algebraic statistics, dinwoodie 1998
-#' #mp()
+#' # code to download m2r:
+#' # note that to do this you should have Macaulay2 installed,
+#' # see https://github.com/musicman3320/m2r and 
+#' # http://www.math.uiuc.edu/Macaulay2/Downloads/
+#' if(!require(devtools)) install.packages("devtools")
+#' devtools::install_github("musicman3320/m2r")
+#' 
+#' 
+#' 
+#' 
 #' 
 #' }
 grobner <- function(mpolyList, varorder = vars(mpolyList), order = 'lex'){
   
+  .Defunct("gb", "m2r",
+    paste0(
+      "grobner is no longer part of the mpoly package.\n",
+      "  See ?grobner for other ways to compute a Grobner basis."
+    )
+  )
+  
   stopifnot(is.mpolyList(mpolyList))
 
   # determine variables
@@ -59,7 +55,7 @@ grobner <- function(mpolyList, varorder = vars(mpolyList), order = 'lex'){
   }  
   
   # initialize sympy variables
-  lapply(as.list(variables), Var)
+  # lapply(as.list(variables), Var) # Var uses sympy
   
   # error if varorder is not a permutation of detected variables
   if(!missing(varorder) && !all(vars(mpolyList) %in% varorder)){
@@ -81,7 +77,7 @@ grobner <- function(mpolyList, varorder = vars(mpolyList), order = 'lex'){
     paste(', order = "', order, '")', sep = ''),
     sep = ''
   )
-  gb <- sympy(pre_grob)
+  # gb <- sympy(pre_grob) # sympy dependent
   gb <- substr(gb, 2, nchar(gb) - 1)
   gb <- gsub('\\*\\*', '\\^', gb) # issue : rational expressions allowed, e.g. "x - 2*y^3/3"
   gb <- gsub('\\*', ' ', gb)    
